@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = 'v0.1.17';
+our $VERSION = 'v0.1.18';
 
 use base 'Exporter'; 
 
@@ -103,7 +103,7 @@ sub check_line {
 sub header {
 
     diag("start swat for $url/$path");
-    diag("debug $debug | try num $try_num | ignore http errors $ignore_http_err")
+    diag("swat version $swat::VERSION | debug $debug | try num $try_num | ignore http errors $ignore_http_err")
 }
 
 sub generate_asserts {
@@ -252,10 +252,6 @@ sub handle_plain {
 
 1;
 
-=head1 ABSTRACT
-
-SWAT is Simple Web Application Test ( Tool )
-
 =head1 SYNOPSIS
 
 SWAT is Simple Web Application Test ( Tool )
@@ -535,7 +531,8 @@ What about to validate web application content with sqlite database entries?
     
     [ map { $_->[0] } @${results} ]
 
-See examples/swat-generators-sqlite3 for working example
+
+As an example take a loot at examples/swat-generators-sqlite3 project
 
 
 =head1 Multiline expressions
@@ -571,6 +568,21 @@ Here are some exmaples:
 
 Multiline expressions are only allowable for perl expressions and generators 
 
+=head1 Generators and Perl Expressions Scope
+
+Swat uses I<perl string eval> when process generators and perl expressions code, be aware of this. 
+Follow L<http://perldoc.perl.org/functions/eval.html> to get more on this.
+
+=head1 PERL5LIB
+
+Swat adds B<$project_root_directory/lib> to PERL5LIB , so this is convient convenient to place here custom perl modules:
+
+
+    example/my-app/lib/Foo/Bar/Baz.pm
+
+As an example take a loot at examples/swat-generators-with-lib/ project
+
+
 =head1 Post requests
 
 Name swat data file as post.txt to make http POST requests.
@@ -604,12 +616,6 @@ C<--data-binary> - Post data sending as is.
 =back
 
 
-=head1 Generators and Perl Expressions Scope
-
-Swat uses I<perl string eval> when process generators and perl expressions code, be aware of this. 
-Follow L<http://perldoc.perl.org/functions/eval.html> to get more on this.
-
-
 =head1 Swat Settings
 
 Swat comes with settings defined in two contexts:
@@ -788,8 +794,14 @@ B<project_dir> - is a project root directory
 
 =back
 
+=head1 Swat Packages
 
-=head2 Prove settings
+Swat packages is distributable archives of swat tests. It's easy to create your own swat packages and share with other. 
+Consider https://github.com/melezhik/swat-packages project for details.
+
+
+
+=head1 Prove settings
 
 Swat utilize L<prove utility|http://search.cpan.org/perldoc?prove> to run tests, so all the swat options I<are passed as is to prove utility>.
 Follow L<prove|http://search.cpan.org/perldoc?prove> utility documentation for variety of values you may set here.
@@ -839,6 +851,10 @@ find
 
 head
 
+=item *
+
+tar
+
 =back
 
 =head1 AUTHOR
@@ -846,6 +862,11 @@ head
 L<Aleksei Melezhik|mailto:melezhik@gmail.com>
 
 
+=head1 Swat Project Home Page
+
+https://github.com/melezhik/swat
+
+
 =head1 Thanks
 
 To the authors of ( see list ) without who swat would not appear to light
